from autogen import ConversableAgent

class TeamMember:
    name: str
    ag_agent: ConversableAgent
    apps: list[str]
    
    @staticmethod
    def from_autogen_agent(agent: ConversableAgent, apps: list[str] = []):
        member = TeamMember()
        member.name = agent.name
        member.ag_agent = agent
        member.apps = apps
        
    def get_apps(self):
        return []
    
    def get_agent(self, llm_config = None) -> tuple:
        return self.ag_agent