from autogen import AssistantAgent
from .ceo import CEO
from .treasurer import Treasurer
from .hr_manager import HRManager

class Govern:
    def __init__(self, llm_config):
        self.llm_config = llm_config
        self.members = [
            CEO(),
            Treasurer(),
            HRManager()
        ]
        
    def get_members(self) -> list[AssistantAgent]:
        return [ member for member in self.members ]


