from datetime import datetime, timedelta

class Clock:
    def __init__(self, time: datetime):
        self.time = time

    def tick(self):
        self.time += timedelta(minutes=10)

    def now(self):
        return self.time
    
    def set_time(self, time: datetime):
        self.time = time
    
    def advance(self, hours: int = None, days: int = None):
        if hours is None and days is None:
            raise ValueError("You must provide either hours or days")
        if hours is not None:
            self.time += timedelta(hours=hours)
        if days is not None:
            self.time += timedelta(days=days)
        return self.time
    
    def __str__(self):
        return f"{self.time} o'clock"
   