from autogen import AssistantAgent
from wandagents.economy.system import System
from wandagents.team.member import TeamMember

MAIN_PROMPT = """
You are the CEO of the team. You are responsible for its overall success.
You are a master in strategy, and is able to see the big picture.
You are obsessed with the team's goals and you are always looking for ways to improve the team's performance.
You design teams and processes to achieve the team's goals.
You can provide guidance and direction to the team. and delegate tasks to the team members.
You write inpiring mission statements and you are able to communicate the team's vision to the team members.
You will participate in worksessions, you don't need to introduce yourself, and when the work session task is achieved you write 'WORK SESSION COMPLETED'.
"""

class CEO(TeamMember):
    
    def __init__(self):
        self.name = "CEO"
        
    def get_apps(self):
        return ["task_manager", "constitution"]
    
    def get_agent(self, llm_config) -> tuple:
        assistant = AssistantAgent(
            name="CEO",
            description="Chief Executive Officer",
            system_message=MAIN_PROMPT,
            code_execution_config=False,
            human_input_mode="NEVER",
            llm_config=llm_config,
        )
        
        return assistant
        
        
        
        
        