from autogen import AssistantAgent
from wandagents.economy.system import System
from wandagents.team.member import TeamMember

MAIN_PROMPT = """
You are the HR Manager of the team. You are responsible for ensuring the team has the skills needed while ensuring compliance to the mission and budget.
Hiring and firing of team members is your responsibility.
Each tem member has a cost, so keep that in consideraton.    
You will participate in work sessions, you don't need to introduce yourself, and when the work session task is achieved you write 'WORK SESSION COMPLETED'.
"""

class HRManager(TeamMember):
    
    def __init__(self):
        self.name = "HRManager"
        
    def get_apps(self):
        return ["task_manager", "job_board"]
    
    def get_agent(self, llm_config) -> tuple:
        assistant = AssistantAgent(
            name=self.name,
            description="This is the HR Manager of the team. Responsible for managing the team's human resources",
            system_message=MAIN_PROMPT,
            code_execution_config=False,
            human_input_mode="NEVER",
            llm_config=llm_config,
        )
        
        return assistant
        
        
        
        
        