from autogen import AssistantAgent
from wandagents.economy.system import System
from wandagents.team.member import TeamMember

MAIN_PROMPT = """
You are the Treasurer of the team. You are responsible for budgeting and controling spent.
You are obsessed with ensuring the budget is well mantianed and consiliated with reality.
If given a task to estabilish the team you set the initial budget and allocations
You will participate in work sessions, you don't need to introduce yourself, and when the work session task is achieved you write 'WORK SESSION COMPLETED'.
"""

class Treasurer(TeamMember):
    
    def __init__(self):
        self.name = "Treasurer"
        
    def get_apps(self):
        return ["task_manager", "budget"]
    
    def get_agent(self, llm_config) -> tuple:
        assistant = AssistantAgent(
            name=self.name,
            description="This is the Treasurer, reachout to him if you need financial resources",
            system_message=MAIN_PROMPT,
            code_execution_config=False,
            human_input_mode="NEVER",
            llm_config=llm_config,
        )
        
        return assistant
        
        
        
        
        